@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Driver;
 BEGIN {
-  $Search::GIN::Driver::VERSION = '0.08';
+  $Search::GIN::Driver::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT:
-
+$Search::GIN::Driver::VERSION = '0.09';
 use Moose::Role;
 
 use Data::Stream::Bulk::Util qw(bulk nil cat unique);
@@ -83,17 +83,19 @@ sub fetch_entries_all {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Search::GIN::Driver - use Moose::Role;
+Search::GIN::Driver - $Search::GIN::Driver::VERSION = '0.09';
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -103,17 +105,13 @@ version 0.08
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
