@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Driver::Pack::UUID;
 BEGIN {
-  $Search::GIN::Driver::Pack::UUID::VERSION = '0.08';
+  $Search::GIN::Driver::Pack::UUID::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT: UUID key packing
-
+$Search::GIN::Driver::Pack::UUID::VERSION = '0.09';
 use Moose::Role;
 
 use namespace::clean -except => [qw(meta)];
@@ -24,17 +24,19 @@ sub pack_ids {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Search::GIN::Driver::Pack::UUID - UUID key packing
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -44,17 +46,13 @@ version 0.08
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
