@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Extract::Delegate;
 BEGIN {
-  $Search::GIN::Extract::Delegate::VERSION = '0.08';
+  $Search::GIN::Extract::Delegate::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT:
-
+$Search::GIN::Extract::Delegate::VERSION = '0.09';
 use Moose::Role;
 use namespace::clean -except => 'meta';
 
@@ -20,30 +20,29 @@ sub extract_values { shift->extract->extract_values(@_) }
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Search::GIN::Extract::Delegate - use Moose::Role;
+Search::GIN::Extract::Delegate - $Search::GIN::Extract::Delegate::VERSION = '0.09';
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
