@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Extract::Multiplex;
 BEGIN {
-  $Search::GIN::Extract::Multiplex::VERSION = '0.08';
+  $Search::GIN::Extract::Multiplex::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT:
-
+$Search::GIN::Extract::Multiplex::VERSION = '0.09';
 use Moose;
 use namespace::clean -except => 'meta';
 
@@ -27,37 +27,35 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Search::GIN::Extract::Multiplex - use Moose;
+Search::GIN::Extract::Multiplex - $Search::GIN::Extract::Multiplex::VERSION = '0.09';
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
-	use Search::GIN::Extract::Multiplex;
+    use Search::GIN::Extract::Multiplex;
 
 =head1 DESCRIPTION
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
