@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Indexable;
 BEGIN {
-  $Search::GIN::Indexable::VERSION = '0.08';
+  $Search::GIN::Indexable::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT:
-
+$Search::GIN::Indexable::VERSION = '0.09';
 use Moose::Role;
 
 requires 'gin_extract_values';
@@ -27,17 +27,19 @@ sub gin_consistent {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Search::GIN::Indexable - use Moose::Role;
+Search::GIN::Indexable - $Search::GIN::Indexable::VERSION = '0.09';
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -47,17 +49,13 @@ version 0.08
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
