@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Keys::Deep;
 BEGIN {
-  $Search::GIN::Keys::Deep::VERSION = '0.07';
+  $Search::GIN::Keys::Deep::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT:
-
+$Search::GIN::Keys::Deep::VERSION = '0.09';
 use Moose::Role;
 use namespace::clean -except => 'meta';
 
@@ -23,37 +23,35 @@ sub process_keys {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Search::GIN::Keys::Deep - use Moose::Role;
+Search::GIN::Keys::Deep - $Search::GIN::Keys::Deep::VERSION = '0.09';
 
 =head1 VERSION
 
-version 0.07
+version 0.09
 
 =head1 SYNOPSIS
 
-	with qw(Search::GIN::Keys::Deep);
+    with qw(Search::GIN::Keys::Deep);
 
 =head1 DESCRIPTION
 
 =head1 AUTHOR
 
-  Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
