@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Query::Manual;
 BEGIN {
-  $Search::GIN::Query::Manual::VERSION = '0.08';
+  $Search::GIN::Query::Manual::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT: Create manual GIN queries
-
+$Search::GIN::Query::Manual::VERSION = '0.09';
 use Moose;
 use namespace::clean -except => 'meta';
 
@@ -52,7 +52,7 @@ sub extract_values {
 }
 
 sub consistent {
-    my ( $self, $obj ) = @_;
+    my ( $self, $index, $obj ) = @_;
 
     if ( my $filter = $self->filter ) {
         return $obj->$filter;
@@ -65,17 +65,19 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Search::GIN::Query::Manual - Create manual GIN queries
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -109,17 +111,13 @@ The keys and values to build the query for.
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
