@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Search::GIN::Query::Set;
 BEGIN {
-  $Search::GIN::Query::Set::VERSION = '0.08';
+  $Search::GIN::Query::Set::AUTHORITY = 'cpan:NUFFIN';
 }
 # ABSTRACT: Create queries with set operations
-
+$Search::GIN::Query::Set::VERSION = '0.09';
 use Moose;
 use namespace::clean -except => 'meta';
 
@@ -57,17 +57,19 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Search::GIN::Query::Set - Create queries with set operations
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -121,17 +123,13 @@ default is "UNION"
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
